

clear all
% close all

ftitle = 'Lund-CIRP';
fimage = '..\images\VR86_Lund-CIRP.png';
flist{1} = '..\simulations\Lund-CIRP\L0p5\';
flist{2} = '..\simulations\Lund-CIRP\L1p0\';
flist{3} = '..\simulations\Lund-CIRP\L2p0\';
% flist{2} = '..\simulations\Lund-CIRP\L3p0\';
% flist{4} = '..\simulations\Lund-CIRP\L4p0\';
flist{4} = '..\simulations\Lund-CIRP\L5p0\';
fleg = {'Initial Bed','Measured','\itL_t\rm = 0.5'...
    '\itL_t\rm = 1.0','\itL_t\rm = 2.0',...
    '\itL_t\rm = 5.0'};

% ftitle = 'Van Rijn';
% fimage = '..\images\VR86_Van_Rijn.png';
% flist{1} = '..\simulations\Van_Rijn\L2p0\';
% % flist{2} = '..\simulations\Van_Rijn\L3p0\';
% flist{2} = '..\simulations\Van_Rijn\L4p0\';
% % flist{4} = '..\simulations\Van_Rijn\L5p0\';
% flist{3} = '..\simulations\Van_Rijn\L6p0\';
% flist{4} = '..\simulations\Van_Rijn\L10p0\';
% fleg = {'Initial Bed','Measured',...
%     '\itL_t\rm = 1.0','\itL_t\rm = 2.0',...
%     '\itL_t\rm = 5.0','\itL_t\rm = 10.0'};

% ftitle = 'Van Rijn';
% fimage = '..\images\VR86_Porosity.png';
% flist{1} = '..\simulations\Van_Rijn\p0p30\';
% flist{2} = '..\simulations\Van_Rijn\p0p35\';
% flist{3} = '..\simulations\Van_Rijn\p0p40\';
% fleg = {'Initial Bed','Measured',...
%     '\itp''_m\rm = 0.30','\itp''_m\rm = 0.35','\itp''_m\rm = 0.40'};

% ftitle = 'Van Rijn';
% fimage = '..\images\VR86_Bedslope.png';
% flist{1} = '..\simulations\Van_Rijn\Ds0p0\';
% % flist{2} = '..\simulations\Van_Rijn\Ds0p1\';
% flist{2} = '..\simulations\Van_Rijn\Ds1p0\';
% flist{3} = '..\simulations\Van_Rijn\Ds5p0\';
% fleg = {'Initial Bed','Measured',...
%     '\itD_s\rm = 0.0','\itD_s\rm = 1.0','\itD_s\rm = 5.0'};

% ftitle = 'Soulsby';
% fimage = '..\images\VR86_Soulsby.png';
% flist{1} = '..\simulations\Soulsby\L1p0\';
% flist{2} = '..\simulations\Soulsby\L2p0\';
% flist{3} = '..\simulations\Soulsby\L5p0\';
% flist{4} = '..\simulations\Soulsby\L10p0\';
% fleg = {'Initial Bed','Measured',...
%     '\itL_t\rm = 1.0','\itL_t\rm = 2.0',...
%     '\itL_t\rm = 5.0','\itL_t\rm = 10.0'};

% c = {'b','g','r','c','m'};
c = {'r','g','c','b','m'};
c = {'m','g','b','c','r'};
% c = {'b','g','m'};

%% Load measurements
h0 = load('..\data\VR86_0hr.txt');
h10 = load('..\data\VR86_10hr.txt');    

%% Load Grid
fpath =  '..\runs\';  
filename = [fpath,'Flow_VR86_grid.h5'];
info = hdf5info(filename);
s = info.GroupHierarchy.Groups;
origin = s.Attributes(6).Value;
nx = s.Attributes(7).Value;
ny = s.Attributes(8).Value;
x = hdf5read(s.Datasets(1));
x = x - 0.05 + origin(1);

figure('Position',[350   366   500   252],'PaperPositionMode','auto')
set(gca,'ydir','reverse','nextplot','add','Box','On',...
    'xlim',[4 14],'ylim',[0.25 0.4],'XMinorTick','On','YMinorTick','on')
plot(h0(:,1),h0(:,2),'k--','linewidth',2)
hh = plot(h10(:,1),h10(:,2),'rd','markersize',5,'markerfacecolor','r');
xlabel('Distance, m')
ylabel('Depth, m')
title(ftitle)

%Initialize goodness of fit statistics
bss = zeros(length(flist),1);
rmse = bss; nrmse = bss; nmae = bss;
R2 = bss; bias = bss;

for i=1:length(flist)
    fpath = flist{i};

    %% Load results
    filename = [fpath,'Flow_VR86_sol.h5'];
    sol = readcmsh5(filename);
    tc = double(sol.Depth.Times);
    h0c = double(reshape(sol.Depth.Values(:,1),nx,ny));
    h0c = h0c(:,2)';
    h10c = double(reshape(sol.Depth.Values(:,tc==10),nx,ny));
    h10c = h10c(:,2)';
    
    %Check Inflow conditions
    Ct = double(reshape(sol.Capacity.Values(:,tc==3),nx,ny));
    Ct = Ct(1,2);
    rs = double(reshape(sol.Fraction_Suspended.Values(:,tc==3),nx,ny));
    rs = rs(1,2);
    Cs = rs*Ct;
    U = double(reshape(sol.Current_Magnitude.Values(:,tc==3),nx,ny));
    U = U(1,2);
    qs = h0c(1)*U*Cs;
    qt = h0c(1)*U*Ct;
    qb = qt*(1-rs);
    H = double(reshape(sol.Wave_Height.Values(:,tc==3),nx,ny));
    H = H(1,2)/sqrt(2);
    
    disp('---------------------------')
    disp(['Velocity = ',num2str(U),' m/s']) %Measured 0.18 m/s
    disp(['Depth = ',num2str(h0c(1)),' m']) %Measured 0.255 m
    disp(['Wave height = ',num2str(H),' m']) %Measured 0.08 m
    disp(['Suspended Concentration = ',num2str(Cs),' kg/m^3'])
    disp(['Total Transport = ',num2str(qt),' kg/m/s']) %Measured 0.0167 kg/m/s
    disp(['Suspended Transport = ',num2str(qs),' kg/m/s']) %Measured 0.0019 kg/m/s
    disp(['Bed Transport = ',num2str(qb),' kg/m/s'])
    
    %% Goodness of fit statistics
    yc = interp1(x,h10c,h10(:,1));
    ym = h10(:,2);
    y0 = interp1(x,h0c,h10(:,1));
    bss(i) = 1-sqrt(mean((yc-ym).^2))/sqrt(mean((y0-ym).^2));
    rmse(i) = sqrt(mean((yc-ym).^2));
    nrmse(i) = sqrt(mean((yc-ym).^2))/(max(ym)-min(ym));
    nmae(i) = mean(abs((yc-ym)))/(max(ym)-min(ym));
    R = corrcoef(yc,ym);
    R2(i) = R(1,2)^2;
    bias(i) = mean(yc-ym);
    
    %% Plotting    
%     plot(x,h0c,'-.r','linewidth',2) %for checking x-axis
    plot(x,h10c,'-','linewidth',2,'color',c{i})
end

disp('--- Goodness of fit statistics  ---')
disp('       10hr')
disp(' BSS    NRMSE    NMAE     R^2   Bias')
for i=1:length(flist)
    fprintf(1,'%6.3f,%7.4f,%7.4f,%7.3f,%7.4f\n',...
        bss(i),nrmse(i),nmae(i),R2(i),bias(i));    
end

legend(fleg,0)
bringtofront(hh)
return

saveas(gcf,fimage)

% hc = double(reshape(sol.Depth.Values(:,end),nx,ny));
% hc = hc(:,2)';
% figure('Position',[350   366   500   252])
% set(gca,'ydir','reverse','nextplot','add','Box','On',...
%     'xlim',[4 14],'ylim',[0.25 0.4],'XMinorTick','On','YMinorTick','on')
% plot(h0(:,1),h0(:,2),'k-')
% plot(h10(:,1),h10(:,2),'ko','markersize',2,'markerfacecolor','k')
% plot(x,hc,'-b','linewidth',2)
% plot(x,h0c,'-.k','linewidth',2)
% xlabel('Distance, m')
% ylabel('Depth, m')

%     fpath = [fpath0,'run',int2str(i),'\'];    
%     fpath =  '..\runs\';  
%     fpath =  '..\runs\run24\';  

